#!/bin/bash

world="/Volumes/Network/courses/ss/dnn/tools/WORLD/build"
sptk="/Volumes/Network/courses/ss/dnn/tools/SPTK-3.9/bin"

wav_dir="data/wav"
resyn_dir="data/resyn"
mgc_dir="data/mgc"
bap_dir="data/bap"
lf0_dir="data/lf0"

mkdir -p $resyn_dir
mkdir -p $bap_dir 
mkdir -p $lf0_dir
mkdir -p $mgc_dir

alpha=0.77
order=59
fft_length=2048

for file in $wav_dir/*.wav
do
    filename="${file##*/}"
    file_id="${filename%.*}"
   
    echo "Starting copy synthesis for "$file_id
    
    echo "WORLD analysis"
    $world/analysis $wav_dir/$file_id.wav ./f0.double ./sp.double ./ap.double
    
    echo "SPTK transform f0 to log f0 and convert format"
    $sptk/x2x +df ./f0.double | $sptk/sopr -magic 0.0 -LN -MAGIC -1.0e+10 > $lf0_dir/$file_id.lf0
    echo "SPTK convert bap format"
    $sptk/x2x +df ./ap.double > $bap_dir/$file_id.bap
    echo "SPTK convert spectrum to mgc"
    $sptk/x2x +df ./sp.double | $sptk/sopr -R -m 32768.0 | $sptk/mcep -a $alpha -m $order -l $fft_length -e 1.0E-8 -j 0 -f 0.0 -q 3 > $mgc_dir/$file_id.mgc
    echo "SPTK convert mgc to spectrum"
    $sptk/mgc2sp -a 0.77 -g 0 -m 59 -l 2048 -o 2 $mgc_dir/$file_id.mgc | $sptk/sopr -d 32768.0 -P | $sptk/x2x +fd > $mgc_dir/$file_id.resyn.sp

    echo "WORLD resynthesis"
    $world/synth 2048 48000 ./f0.double $mgc_dir/$file_id.resyn.sp ./ap.double $resyn_dir/$file_id.wav


    rm ./f0.double ./sp.double ./ap.double $mgc_dir/$file_id.resyn.sp
    echo "---------------------"

done

echo All finished

