#!/bin/bash

DUMPFEATS=scripts/dumpfeats
UTTSDIR=utt
FEATURE_SCRIPTS=data/resources
CLEANUP_HLED_SCRIPT=${FEATURE_SCRIPTS}/cleanup_dumped_features.hled

mkdir -p alignment/labels/mono
mkdir -p alignment/labels/full

for utt in ${UTTSDIR}/*.utt
do
	base=`basename ${utt} .utt`
	echo "Dumping features from "${utt}
	${DUMPFEATS} -eval ${FEATURE_SCRIPTS}/extra_feats.scm -relation Segment -feats ${FEATURE_SCRIPTS}/label.feats -output tmp.feats ${utt}

	echo "Converting to monophone labels"
	awk -f ${FEATURE_SCRIPTS}/label-mono.awk tmp.feats > mono.lab
	# get rid of unwanted spaces and put into proper HTK format, and drop all timestamps
	HLEd -b -l /tmp /dev/null mono.lab

	echo "Converting to full context labels"
	awk -f ${FEATURE_SCRIPTS}/label-full.awk tmp.feats | sed 's/pau/\#/g'> full.lab
	HLEd -b -l /tmp /dev/null full.lab

	# append the full-context labels to the monophone label files (what HTK calls "level 2 labels")
	paste -d" " /tmp/mono.lab /tmp/full.lab > /tmp/combined.lab

	# then clean up the labels a bit (merge consecutive silence labels)
	HLEd -T 1 -b -l . ${CLEANUP_HLED_SCRIPT} /tmp/combined.lab


	# then split back into separate monophone and full-context label files
	cut -d" " -f1 combined.lab > alignment/labels/mono/${base}.lab 
	cut -d" " -f2 combined.lab > alignment/labels/full/${base}.lab 

	rm -f tmp.feats mono.lab full.lab combined.lab
done

echo Assembling monophone MLF
HLEd -b -l '*' -i utts.mlf /dev/null alignment/labels/mono/*.lab

echo Assembling full-context MLF
HLEd -b -l '*' -i utts_full.mlf /dev/null alignment/labels/full/*.lab

echo Making a phone list
cut -d" " -f3 utts.mlf | sort -u | grep -v "\." | grep -v "MLF" > alignment/phone_list
